# Ethereum Tester Client

[![Build Status](https://travis-ci.org/pipermerriam/ethereum-tester-client.png)](https://travis-ci.org/pipermerriam/ethereum-tester-client)
   

Python client for testing applications that use either the
[ethereum-rpc-client](https://github.com/pipermerriam/ethereum-rpc-client) or the [ethereum-ipc-client](https://github.com/pipermerriam/ethereum-ipc-client).
